import pandas as pd
import geopandas as gpd
import matplotlib.pyplot as plt
from descartes.patch import PolygonPatch

###load in geojson file with data about Landkreise in Germany (export of data from Eurostat https://ec.europa.eu/eurostat/de/web/gisco/geodata/reference-data/administrative-units-statistical-units/nuts) using geopandas reader

NUTS3_map = gpd.read_file("GermanyNUTS3.txt")

###join the geodataframe with pandas dataframe using pandas joiner pd.join()

merged_df = NUTS3_map.set_index("AGS").join(node_edge_product_actor.set_index("AGS"))
merged_df.reset_index(level=0, inplace=True)

###mapping with matplotlib
###set a variable that will call whatever column from pandas dataframe which should be visualised on the map

variable = "product_quantity"

###set the range for the choropleth

vmin = 0.0
vmax = node_edge_product_actor[variable].max()

###create figure and axes for matplotlib

fig, ax = plt.subplots(1, figsize=(10, 10))

###create map based on geodataframe and pandas dataframe, gpd.plot()

merged_df.plot(column = variable, cmap = "Blues", linewidth = 0.8, ax = ax, edgecolor = "0.8", figsize=(10, 10), vmin=vmin, vmax=vmax, aspect=1)

###remove axis

ax.axis("off")

###add title

ax.set_title("Food supply chain network for Germany on NUTS-3 level \n Choropleth map for: {} (quantity in tons per year) \n handled by {}".format(product, actor), fontdict = {"fontsize": "14", "fontweight": "3", "horizontalalignment":"center"})

###create colorbar as a legend for the map

sm = plt.cm.ScalarMappable(cmap = "Blues", norm = plt.Normalize(vmin=vmin, vmax=vmax))

###empty array for the data range

sm._A = []

###add the colorbar to the figure

cbar = fig.colorbar(sm, shrink=0.6)

###show plot

#plt.show()